View source: R/plot_occ_spatial.R
| plot_occ_spatial | R Documentation |
This function summarises occurrence data in a spatial context.
plot_occ_spatial(data, range, za, ptheme)
data |
|
range |
|
za |
shapefile of South Africa read in as an |
ptheme |
ggplot theme object |
The function draws three plots showing occurrence records overlaid on South Africa. Plots are written to the species directory.
Spatial JPEG plots: 1) occ_map_{sppselect}; 2) occ_map_decadal_{sppselect}; and 3) occ_map_inset_{sppselect}
The size of the text and other elements of the plots can be change by customising the theme object.
Dominic Henry
## Not run:
plot_occ_spatial(occ_data_sf, range, za, ptheme)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.